{% extends 'oscar/checkout/preview.html' %}
{% load currency_filters %}
{% load url from future %}
{% load i18n %}

{% block payment_method %}
    <div class="span6">
    <div class="sub-header">
        <h2>{% trans "Payment" %}</h2>
    </div>
    <div class="well well-success">
        <p>{% blocktrans with amount=order_total.incl_tax|currency %}<strong>{{ amount }}</strong> will be debited from your bankcard.{% endblocktrans %}</p>
        <div class="alert-actions">
            <a href="{% url 'checkout:payment-details' %}" class="btn">{% trans "Change payment details" %}</a>
        </div>
    </div>
</div>
{% endblock %}

{% block hiddenforms %}
    {{ bankcard_form.as_p }}
    {{ billing_address_form.as_p }}
{% endblock %}
